@@ -8,6 +8,7 @@ import community
 import time
 import shutil
 import h5py
+import site, sysconfig
 from subprocess import check_call, Popen, PIPE
 
 
@@ -516,3 +517,55 @@ def read_tsv(in_file):
         genes.append(in_table[i,0])
         in_mat_num[i-1,:] = in_table[i,1:]
     return(in_mat_num, genes, cells)
+
+
+def find_string_db_dir(stringdb_dir):
+    organism_action_files = {
+        'hsapiens':'9606.protein.actions.v11.0.txt',
+        'mmusculus':'10090.protein.actions.v11.0.txt'
+    }
+    ## double check that it exists!
+    putative_human_file = os.path.join(stringdb_dir,organism_action_files['hsapiens'])
+    if not os.path.isfile(putative_human_file):
+        print("we couldn't find the string-db interactions in the supplied string_db dir:")
+        print(stringdb_dir)
+        print("will look around a bit!")
+        ## gather a bunch of possible locations dependeing on if being run as a script or not
+        no_import = False
+        try:
+            from pyminer import pyminer_objs
+        except:
+            print("couldn't import! This must be a script")
+            no_import = True
+        dirs_to_try = []
+        if not no_import:
+            dirs_to_try.append(os.path.dirname(pyminer_objs.__file__))
+        if "getsitepackages" in dir(site):
+            site_packs = site.getsitepackages()
+            for i in range(len(site_packs)):
+                site_packs[i]=os.path.join(site_packs[i],"pyminer")
+            dirs_to_try += site_packs
+        dirs_to_try.append(os.path.join(sysconfig.get_paths()["purelib"],"pyminer"))
+        ## now try the locations
+        found_it = False
+        for test_dir in dirs_to_try:
+            putative_relative_human_file = os.path.join(test_dir,organism_action_files['hsapiens'])
+            print(putative_relative_human_file)
+            if os.path.isfile(putative_relative_human_file):
+                print("\n\nFound it!\n", "using this as the stringdb_dir:",test_dir)
+                stringdb_dir = test_dir
+                found_it = True
+        if not found_it:
+            print("\n\n\n\nWARNING! couldn't find the right files in the stringdb_dir:",stringdb_dir)
+            string_db_dir = None
+    return(stringdb_dir)
+
+
+def get_bins(total_vars, bin_size=5000):
+    bins = []
+    cur_bin = 0
+    while cur_bin<total_vars:
+        bins.append(min(cur_bin, total_vars))
+        cur_bin+=bin_size
+    bins.append(total_vars)
+    return(bins)
\ No newline at end of file
