@@ -195,7 +195,7 @@ else:
 
 if len(list(set(grouping_vector))) == 1:
     one_group = True
-    sys.exit('only one sample group, nothing to calculate')
+    print('only one sample group, nothing to calculate')
 else:
     one_group = False
 
@@ -386,6 +386,13 @@ def ray_get_global_cell_type_aov_stats(indices,
     max_index = max(indices)
     min_index = min(indices)
 
+    ## log in case there is only 1 group
+    print(len(list_of_k_sample_indices))
+    if len(list_of_k_sample_indices)==0:
+        one_group = True
+    else:
+        one_group = False
+    print("one_group:",one_group)
     ## make the ray_list_of_k_sample_indices arrays
     ray_list_of_k_sample_indices = []
     for i in range(len(list_of_k_sample_indices)):
@@ -442,36 +449,41 @@ def ray_get_global_cell_type_aov_stats(indices,
 
         #########################
         ## group vars
-        group_percent_express = np.zeros((in_mem_express.shape[0],len(ray_list_of_k_sample_indices)))
-        group_non_zero_mean = np.zeros((in_mem_express.shape[0],len(ray_list_of_k_sample_indices)))
-        for i in range(len(ray_list_of_k_sample_indices)):
-            ## subset
-            temp_binary_int_subset = temp_binary_int[:,ray_list_of_k_sample_indices[i]]
-            ##
-            temp_num_express_subset = np.sum(temp_binary_int_subset, axis=1)
-            #print(temp_num_express_subset)
-            #print(ray_list_of_k_sample_indices[i].shape[0])
-            #print(group_percent_express[:,i])
-            group_percent_express[:,i] = temp_num_express_subset/ray_list_of_k_sample_indices[i].shape[0]## it's a 1 dim array, so this is how many cells are in the group
-            group_non_zero_mean[:,i] = np.sum(in_mem_express[:,ray_list_of_k_sample_indices[i]])/temp_num_express_subset
-        
-        for i in range(in_mem_express.shape[0]):
-            index=idx_range[i]
-            group_percent_express_dict[index] = group_percent_express[i,:].tolist()
-            group_non_zero_mean_dict[index] = group_non_zero_mean[i,:].tolist()
-        
-        ##################
-        ## aov vars
-        for i in range(in_mem_express.shape[0]):
-            index=idx_range[i]
-            if np.sum(temp_binary_int[i,:]) == 0:
-                aov_dict[index] = [np.nan,np.nan]
-            list_of_group_values=[]
-            for group in range(0,len(ray_list_of_k_sample_indices)):
-                list_of_group_values.append(in_mem_express[i,ray_list_of_k_sample_indices[group]])
-                
-            return_val = list(aov(*list_of_group_values))
-            aov_dict[index] = return_val
+        if not one_group:
+            group_percent_express = np.zeros((in_mem_express.shape[0],len(ray_list_of_k_sample_indices)))
+            group_non_zero_mean = np.zeros((in_mem_express.shape[0],len(ray_list_of_k_sample_indices)))
+            for i in range(len(ray_list_of_k_sample_indices)):
+                ## subset
+                temp_binary_int_subset = temp_binary_int[:,ray_list_of_k_sample_indices[i]]
+                ##
+                temp_num_express_subset = np.sum(temp_binary_int_subset, axis=1)
+                #print(temp_num_express_subset)
+                #print(ray_list_of_k_sample_indices[i].shape[0])
+                #print(group_percent_express[:,i])
+                group_percent_express[:,i] = temp_num_express_subset/ray_list_of_k_sample_indices[i].shape[0]## it's a 1 dim array, so this is how many cells are in the group
+                group_non_zero_mean[:,i] = np.sum(in_mem_express[:,ray_list_of_k_sample_indices[i]])/temp_num_express_subset
+            
+            for i in range(in_mem_express.shape[0]):
+                index=idx_range[i]
+                group_percent_express_dict[index] = group_percent_express[i,:].tolist()
+                group_non_zero_mean_dict[index] = group_non_zero_mean[i,:].tolist()
+            
+            ##################
+            ## aov vars
+            for i in range(in_mem_express.shape[0]):
+                index=idx_range[i]
+                if np.sum(temp_binary_int[i,:]) == 0:
+                    aov_dict[index] = [np.nan,np.nan]
+                list_of_group_values=[]
+                for group in range(0,len(ray_list_of_k_sample_indices)):
+                    list_of_group_values.append(in_mem_express[i,ray_list_of_k_sample_indices[group]])
+                    
+                return_val = list(aov(*list_of_group_values))
+                aov_dict[index] = return_val
+        else:
+            group_percent_express_dict[index]=global_percent_express_dict[index]
+            group_non_zero_mean_dict[index]=global_non_zero_mean_dict[index]
+            aov_dict[index]=[np.nan,np.nan]
 
         #################
         ## index incrementing 
@@ -615,7 +627,7 @@ def ray_get_anova(indices,
 list_of_k_sample_indices = sample_k_lists
 #print(list_of_k_sample_indices)
 
-if not one_group:
+if True:#not one_group:
     
     sample_names = list(title)[1:]
     #print(sample_names)
@@ -921,7 +933,7 @@ all_sig_enriched_files=[]
 all_sig_enriched_gprof_files = []
 FDR_cutoff = args.FDR_cutoff
 zscore_cutoff = args.Zscore
-if not one_group:
+if True:#not one_group:
     anova_output = [['Variable', 'F', 'uncorrected_p-val', 'BH_corrected_p-val','-log10(BH_cor_p-val)']]
     aov_uncorrected_p_val_list=[]
 
