@@ -487,14 +487,15 @@ if do_sum_neg or args.rho_cutoff==None or args.log_odds:
     ## run the bootstrap negative control for finding sum negative relationships
     ## first get a bin_size random set of variables to do the negative control on
     neg_control_sample_idxs = np.arange(len(IDlist))
+    print(neg_control_sample_idxs)
     ## remove any genes that are zero in all samples
     non_zero_idxs = np.where(np.sum(infile,axis=1)>0)[0]
     neg_control_sample_idxs = neg_control_sample_idxs[non_zero_idxs]
     np.random.shuffle(neg_control_sample_idxs)
     #print(np.shape(neg_control_sample_idxs))
-    bin_size = min([bin_size, np.shape(neg_control_sample_idxs)[0]])
-    #print(bin_size)
-    neg_control_sample_idxs = neg_control_sample_idxs[:bin_size]
+    neg_ctrl_bin_size = min([bin_size, np.shape(neg_control_sample_idxs)[0]])
+    print("bin_size",neg_ctrl_bin_size)
+    neg_control_sample_idxs = neg_control_sample_idxs[:neg_ctrl_bin_size]
     ##############################################################
     ## 11/14/2020
     ## add lowest & highest % expression to make sure we cover the whole range
@@ -524,93 +525,102 @@ if do_sum_neg or args.rho_cutoff==None or args.log_odds:
         neg_control_subset_mat[i,:] = neg_control_subset_mat[i,temp_row_shuffle_order]
 
     ## get the spearman_rhos for the shuffled matrix
-    r=no_p_spear(neg_control_subset_mat, neg_control_subset_mat, axis = 1, prop=args.prop, log_odds = args.log_odds)#, log_odds_correction = log_odds_correction)
-    linear_rho = get_linear_triangle(r[:bin_size,:bin_size], bin_size)
-    #########################################
-    ## THIS IS WHERE WE SET THE LOG-ODDS BIAS CORRECTION. It's just the median of the null distribution to center it & future comparisons
-    if args.log_odds:
-        log_odds_correction = np.median(linear_rho)
-        print("\n\n\nlog_odds_correction:", log_odds_correction,"\n\n\n\n")
-        linear_rho -= log_odds_correction
+    print("neg_control_subset_mat shape:",np.shape(neg_control_subset_mat)[0])
+    if np.shape(neg_control_subset_mat)[0]<2:
+        ## this is likely a bad input, but handle it just in case it comes up
+        r=np.zeros((neg_ctrl_bin_size,neg_ctrl_bin_size))
+        linear_rho = np.zeros(neg_ctrl_bin_size)
+        neg_cutoff=0
+        FPR=0
+        rho_cutoff = 0
+        args.rho_cutoff = 0
     else:
-        log_odds_correction = 0
-    #########################################
-    print("min of negative control is now:", np.min(linear_rho))
-    print("median of negative control is now:", np.median(linear_rho))
-    print("max of negative control is now:", np.max(linear_rho))
-    print("rho shape",np.shape(r))
-    
-    if single_cutoff:
-        print("linear_rho.shape:",linear_rho.shape)
-        neg_idxs = np.where(linear_rho<0)[0]
-        print("np.where(linear_rho<0)",np.where(linear_rho<0))
-        pos_idxs = np.where(linear_rho>0)[0]
-        negative_control_negative_rho_vect = linear_rho[neg_idxs]
-        negative_control_positive_rho_vect = linear_rho[pos_idxs]
-        #calculate_mad(negative_control_negative_rho_vect)
-
-        ## plot the average Rho per negative correlation
-        #print(negative_control_negative_rho_vect)
+        r=no_p_spear(neg_control_subset_mat, neg_control_subset_mat, axis = 1, prop=args.prop, log_odds = args.log_odds)#, log_odds_correction = log_odds_correction)
+        linear_rho = get_linear_triangle(r[:neg_ctrl_bin_size,:neg_ctrl_bin_size], neg_ctrl_bin_size)
+        #########################################
+        ## THIS IS WHERE WE SET THE LOG-ODDS BIAS CORRECTION. It's just the median of the null distribution to center it & future comparisons
+        if args.log_odds:
+            log_odds_correction = np.median(linear_rho)
+            print("\n\n\nlog_odds_correction:", log_odds_correction,"\n\n\n\n")
+            linear_rho -= log_odds_correction
+        else:
+            log_odds_correction = 0
+        #########################################
+        print("min of negative control is now:", np.min(linear_rho))
+        print("median of negative control is now:", np.median(linear_rho))
+        print("max of negative control is now:", np.max(linear_rho))
+        print("rho shape",np.shape(r))
         
-        if not args.transpose:
-            neg_cor_density_x, neg_cor_density_y = get_density(negative_control_negative_rho_vect)
-            pos_cor_density_x, pos_cor_density_y = get_density(negative_control_positive_rho_vect)
-            ## this is only for gene-gene correlations, not sample-sample
-            print(args.adj_list_out)
-            out_dir = os.path.dirname(args.adj_list_out)
-            sum_neg_plot = os.path.join(out_dir,'boostrap_neg_cor_rhos.png')
-            print("plotting boostrap_neg_cor_rhos.png")
-            plot_one_density(neg_cor_density_x, neg_cor_density_y, sum_neg_plot, label="density of negative correlation null distribution")
-            pos_rho_plot = os.path.join(out_dir,'boostrap_pos_cor_rhos.png')
-            print("plotting boostrap_pos_cor_rhos.png")
-            plot_one_density(pos_cor_density_x, pos_cor_density_y,pos_rho_plot, label="density of positive correlation null distribution")
+        if single_cutoff:
+            print("linear_rho.shape:",linear_rho.shape)
+            neg_idxs = np.where(linear_rho<0)[0]
+            print("np.where(linear_rho<0)",np.where(linear_rho<0))
+            pos_idxs = np.where(linear_rho>0)[0]
+            negative_control_negative_rho_vect = linear_rho[neg_idxs]
+            negative_control_positive_rho_vect = linear_rho[pos_idxs]
+            #calculate_mad(negative_control_negative_rho_vect)
 
-            ## plot the distribution of all bootstrap negative control Rhos
-            neg_cor_density_x, neg_cor_density_y = get_density(linear_rho)
-            sum_neg_plot = os.path.join(out_dir,'boostrap_cor_rhos.png')
-            print("plotting boostrap_cor_rhos.png")
-            plot_one_density(neg_cor_density_x, neg_cor_density_y, sum_neg_plot,label="density of all correlation null distribution")
+            ## plot the average Rho per negative correlation
+            #print(negative_control_negative_rho_vect)
+            
+            if not args.transpose:
+                neg_cor_density_x, neg_cor_density_y = get_density(negative_control_negative_rho_vect)
+                pos_cor_density_x, pos_cor_density_y = get_density(negative_control_positive_rho_vect)
+                ## this is only for gene-gene correlations, not sample-sample
+                print(args.adj_list_out)
+                out_dir = os.path.dirname(args.adj_list_out)
+                sum_neg_plot = os.path.join(out_dir,'boostrap_neg_cor_rhos.png')
+                print("plotting boostrap_neg_cor_rhos.png")
+                plot_one_density(neg_cor_density_x, neg_cor_density_y, sum_neg_plot, label="density of negative correlation null distribution")
+                pos_rho_plot = os.path.join(out_dir,'boostrap_pos_cor_rhos.png')
+                print("plotting boostrap_pos_cor_rhos.png")
+                plot_one_density(pos_cor_density_x, pos_cor_density_y,pos_rho_plot, label="density of positive correlation null distribution")
 
-        print("\n\ncalculating negative correlation FPR cutoff from null distribution:")
-        #neg_cutoff = get_FPR_cutoff(negative_control_negative_rho_vect,FPR)
-        #neg_cutoff, FPR = get_Z_cutoff(negative_control_negative_rho_vect, z=3)
-        if args.log_odds:
-            neg_cutoff, FPR = get_empiric_FPR(negative_control_negative_rho_vect)
+                ## plot the distribution of all bootstrap negative control Rhos
+                neg_cor_density_x, neg_cor_density_y = get_density(linear_rho)
+                sum_neg_plot = os.path.join(out_dir,'boostrap_cor_rhos.png')
+                print("plotting boostrap_cor_rhos.png")
+                plot_one_density(neg_cor_density_x, neg_cor_density_y, sum_neg_plot,label="density of all correlation null distribution")
+
+            print("\n\ncalculating negative correlation FPR cutoff from null distribution:")
+            #neg_cutoff = get_FPR_cutoff(negative_control_negative_rho_vect,FPR)
+            #neg_cutoff, FPR = get_Z_cutoff(negative_control_negative_rho_vect, z=3)
+            if args.log_odds:
+                neg_cutoff, FPR = get_empiric_FPR(negative_control_negative_rho_vect)
+            else:
+                neg_cutoff, FPR = get_empiric_FPR(negative_control_negative_rho_vect)
+            print('\nEmpiric FPR for anti-corr:',FPR)
+            print('\nEmpiric neg_cutoff for anti-corr:',neg_cutoff)
+            print("\n\ncalculating adj list FPR cutoffs from null distribution:")
+            #pos_cutoff = get_FPR_cutoff(negative_control_positive_rho_vect,pos_FPR, positive = True)
+            if args.log_odds:
+                pos_z_cut = 3.0
+                pos_cutoff = get_Z_cutoff(negative_control_positive_rho_vect, z=pos_z_cut, positive = True, cap=None)
+                neg_cutoff_adj_list, dummy = get_Z_cutoff(negative_control_negative_rho_vect, z=pos_z_cut, positive = False, cap=None)
+            else:
+                pos_z_cut = 5.5
+                pos_cutoff = get_Z_cutoff(negative_control_positive_rho_vect, z=pos_z_cut, positive = True)
+                neg_cutoff_adj_list, dummy = get_Z_cutoff(negative_control_negative_rho_vect, z=pos_z_cut, positive = False)
+            rho_cutoff = pos_cutoff
+            args.rho_cutoff = pos_cutoff
+            #sys.exit()
         else:
-            neg_cutoff, FPR = get_empiric_FPR(negative_control_negative_rho_vect)
-        print('\nEmpiric FPR for anti-corr:',FPR)
-        print('\nEmpiric neg_cutoff for anti-corr:',neg_cutoff)
-        print("\n\ncalculating adj list FPR cutoffs from null distribution:")
-        #pos_cutoff = get_FPR_cutoff(negative_control_positive_rho_vect,pos_FPR, positive = True)
-        if args.log_odds:
-            pos_z_cut = 3.0
-            pos_cutoff = get_Z_cutoff(negative_control_positive_rho_vect, z=pos_z_cut, positive = True, cap=None)
-            neg_cutoff_adj_list, dummy = get_Z_cutoff(negative_control_negative_rho_vect, z=pos_z_cut, positive = False, cap=None)
-        else:
-            pos_z_cut = 5.5
-            pos_cutoff = get_Z_cutoff(negative_control_positive_rho_vect, z=pos_z_cut, positive = True)
-            neg_cutoff_adj_list, dummy = get_Z_cutoff(negative_control_negative_rho_vect, z=pos_z_cut, positive = False)
-        rho_cutoff = pos_cutoff
-        args.rho_cutoff = pos_cutoff
-        #sys.exit()
-    else:
-        ##############################################################
-        ## this means that we just have a dynamic negative rho cutoff as determined by gene expression sparsity
-        rho_cutoff_vect, FPR_vect = get_rho_cutoff_vect(r, neg_control_sample_idxs, gene_non_zero_mean, os.path.dirname(args.adj_list_out))
-##############################################################################################################################################
+            ##############################################################
+            ## this means that we just have a dynamic negative rho cutoff as determined by gene expression sparsity
+            rho_cutoff_vect, FPR_vect = get_rho_cutoff_vect(r, neg_control_sample_idxs, gene_non_zero_mean, os.path.dirname(args.adj_list_out))
+    ##############################################################################################################################################
 ##############################################################################################################################################
 ##############################################################################################################################################
 ## Do all of the comparisons
 
 start = time.time()
-if total_vars==bins[-1] and args.hdf5_out:
+if total_vars==bins[1] and args.hdf5_out:
     print("total num vars is equal to the number of bins, so we'll do it in one go")
     r=no_p_spear(infile[:,:], axis = 1, prop=args.prop, log_odds = args.log_odds, log_odds_correction = log_odds_correction)
     print(r.shape)
     print(spear_out_hdf5.shape)
     spear_out_hdf5[:,:]=r[:,:]
 else:
-
     print("finding block...")
     for i in range(0,(len(bins)-1)):
         temp_first = infile[bins[i]:bins[i+1],]
