@@ -9,9 +9,11 @@ import random
 import h5py
 try:
     from pyminer.common_functions import *
+    from pyminer.pyminer_convert_to_scanpy import adata_to_pm_input
     from pyminer.pyminer_objs import pyminer_obj
 except:
     from common_functions import *
+    from pyminer_convert_to_scanpy import adata_to_pm_input
     from pyminer_objs import pyminer_obj
 
 ##############################################################
@@ -193,7 +195,15 @@ def pyminer_analysis(infile=None,
                     string_db_dir='/usr/local/lib/cell_signals/',
                     dpi = 360,
                     verbose=False,
+                    adata=None,
+                    analysis_dir=None,
                      **kwargs):
+    if adata is not None:
+        if (analysis_dir==None):
+            raise Exception("to run pyminer with scanpy input, you need to give us a directory to work in.\nPlease include the analysis_dir argument:\n'analysis_dir=</path/to/dir/>'")
+        infile, ID_list, columns = adata_to_pm_input(adata, analysis_dir)
+        ## these will always be converted to a pyminer hdf5 file
+        do_h5_py = True
     infile = os.path.realpath(infile)
     temp_dir = get_file_path(infile)
     all_calls = [' '.join(sys.argv)]
