@@ -785,7 +785,10 @@ def get_empiric_FPR(vect, FPR=1000, positive = False):
     #if not positive:
     #    vect_original = vect_original * -1
     sort_order = np.sort(vect_original)
-    cutoff = sort_order[target_index]
+    if sort_order.shape[0]==0:
+        cutoff=0
+    else:
+        cutoff = sort_order[target_index]
     print('cutoff:',cutoff)
     if not positive:
         num_sig = np.sum(np.array(vect_original<cutoff,dtype = bool))
